# simplebuild

A very simple to use build system for projects with primarily C++/Python code,
intended for usage by scientific developers without a strong SW-engineering
background.

Please refer to the website for details about usage and installation:
https://mctools.github.io/simplebuild/
